<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryRef" :rules="rules" :inline="true" v-show="showSearch" label-position="left" label-width="50px">
      <el-row :gutter="20">
        <el-col :span="6">
          <el-form-item label="料号" prop="itemNumber">
            <el-input
              v-model="queryParams.itemNumber"
              placeholder="请输入料号"
              clearable
              @keyup.enter="handleQuery"
            />
          </el-form-item>
        </el-col>
        <el-col :span="18" style="text-align: right;">
          <el-form-item>
              <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
              <el-button icon="Refresh" @click="resetQuery">重置</el-button>
            </el-form-item>
        </el-col>
      </el-row>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <right-toolbar v-model:showSearch="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <HxlhTable
        style="width: 100%"
        :columns="columns"
        :data="processCapacityManagementList"
        :loading="loading"
        :height="height"
        :page="page"
        @on-checkbox="handleCheckboxChange"
        @changePageNo="changePageNo"
        @changePageSize="changePageSize"
    >
      <template #status="{row}" >
          <vxe-tag v-if = "row.capacityType === '0'" status="success">标准工时</vxe-tag>
          <vxe-tag v-if = "row.capacityType === '1'" status="primary">固定周期</vxe-tag>
      </template>
    </HxlhTable>
  </div>
</template>

<script setup name="ProcessCapacityManagement">
import { listProcessCapacityManagement, getProcessCapacityManagement, delProcessCapacityManagement, addProcessCapacityManagement, updateProcessCapacityManagement } from "@/api/basicData/processCapacityManagement/processCapacityManagement";
import HxlhTable from '@/components/HxlhTable'

const { proxy } = getCurrentInstance();

const processCapacityManagementList = ref([]);
const open = ref(false);
const loading = ref(false);
const showSearch = ref(true);
const ids = ref([]);
const single = ref(true);
const multiple = ref(true);
const title = ref("");
const height = ref(document.documentElement.clientHeight - 230 + "px;")
const { aps_capacity_type } = proxy.useDict('aps_capacity_type');//产能类型

// 分页属性
const page = ref({
  total: 0,
  current: 1,
  size: 10
});

const data = reactive({
  form: {},
  queryParams: {
    pageNum: 1,
    pageSize: 10,
    itemNumber: null,
  },
  rules: {
    itemNumber: [
      { required: true, message: "料号不能为空", trigger: "blur" }
    ],
  }
});

// 表格配置 
const columns = ref([
  { type: 'seq', title: '序号', width: 60 },
  {
    title: '料号',
    field: 'itemNumber',
  },
  {
    title: '产能类型',
    field: 'capacityType',
    slots: { default: 'status' },
    /* formatter: (({ cellValue, row, column }) => {
      if (cellValue) {
        for(let i=0;i<aps_capacity_type.value.length;i++){
          if(cellValue===aps_capacity_type.value[i].value){
            return aps_capacity_type.value[i].label
          }
        }
      }
      return '';
    }) */
  },
  {
    title: '工序名称',
    field: 'processName',
  },
  {
    title: '工艺路线ID',
    field: 'processRouteId',
  },
  {
    title: '工时',
    field: 'workTime',
  },
  {
    title: '生效日期',
    field: 'effectiveDate',
  },
  {
    title: '失效日期',
    field: 'expiringDate',
  },
  {
    title: '集成日期',
    field: 'integrationDate',
  },
]);

const { queryParams, form, rules } = toRefs(data);

/** 查询工序级产能数据管理列表 */
function getList() {
  loading.value = true;
  listProcessCapacityManagement(queryParams.value).then(response => {
    processCapacityManagementList.value = response.rows;
    page.value.total = response.total;
    loading.value = false;
  });
}

// 取消按钮
function cancel() {
  open.value = false;
  reset();
}

// 表单重置
function reset() {
  form.value = {
    id: null,
    itemNumber: null,
    capacityType: null,
    processNumber: null,
    processName: null,
    processRouteId: null,
    workTime: null,
    effectiveDate: null,
    expiringDate: null,
    integrationDate: null,
    createBy: null,
    createTime: null,
    updateBy: null,
    updateTime: null
  };
  proxy.resetForm("processCapacityManagementRef");
}

/** 搜索按钮操作 */
function handleQuery() {
  proxy.$refs["queryRef"].validate(valid => {
    if (valid) {
      page.value.current = 1;
      queryParams.value.pageNum = 1;
        getList();
      }
  });
}

/** 重置按钮操作 */
function resetQuery() {
  proxy.resetForm("queryRef");
  processCapacityManagementList.value = null;
  page.value.total = 0;
  page.value.current = 1;
  queryParams.value.pageNum = 1;
  // handleQuery();
}

/** 修改按钮操作 */
function handleUpdate(row) {
  reset();
  const _id = row.id || ids.value
  getProcessCapacityManagement(_id).then(response => {
    form.value = response.data;
    open.value = true;
    title.value = "修改工序级产能数据管理";
  });
}

/** 提交按钮 */
function submitForm() {
  proxy.$refs["processCapacityManagementRef"].validate(valid => {
    if (valid) {
      if (form.value.id != null) {
        updateProcessCapacityManagement(form.value).then(response => {
          proxy.$modal.msgSuccess("修改成功");
          open.value = false;
          getList();
        });
      } else {
        addProcessCapacityManagement(form.value).then(response => {
          proxy.$modal.msgSuccess("新增成功");
          open.value = false;
          getList();
        });
      }
    }
  });
}

/** 删除按钮操作 */
function handleDelete(row) {
  const _ids = row.id || ids.value;
  proxy.$modal.confirm('是否确认删除工序级产能数据管理编号为"' + _ids + '"的数据项？').then(function() {
    return delProcessCapacityManagement(_ids);
  }).then(() => {
    getList();
    proxy.$modal.msgSuccess("删除成功");
  }).catch(() => {});
}

/** 导出按钮操作 */
function handleExport() {
  proxy.download('processCapacityManagement/processCapacityManagement/export', {
    ...queryParams.value
  }, `processCapacityManagement_${new Date().getTime()}.xlsx`)
}

function changePageNo(currentPage) {
  page.value.current = currentPage;
  queryParams.value.pageNum = currentPage;
  getList();
}

function changePageSize(pageSize) {
  page.value.current = 1;
  queryParams.value.pageNum = 1;
  queryParams.value.pageSize = pageSize;
  getList();
}

// getList();
</script>
